nlpar(subiterations=100)

display ' '
display '************************     Start Table 1 Results     ************************'
display '*******************************************************************************'
display ' '

* In this set of regressions, we use our ZY (method 1); this only affects DSBOZY
@setzy 1

* Set the sample so OLS regressions will be the same as the NLLS regressions
smpl 63:3 94:3

* Run OLS to generate initial values
linreg yg / ygr
# constant cng{1 to 3} yg{1 to 3} mu{1} dtb3{1 to 3} dlhur{1 to 3} $
           spg{1 to 3} lcnmly{1}
set ygf = yg - ygr

linreg cng
# constant ygf
compute cngconst = %beta(1)
compute cngygf = %beta(2)

* Set initial estimates
compute nlconst = cngconst, nlygf = cngygf
compute theta = .1
nonlin nlconst nlygf theta

instruments constant cng{1 to 3} yg{1 to 3} mu{1} dtb3{1 to 3} dlhur{1 to 3} $
            spg{1 to 3} lcnmly{1}
frml fl = cng{0}-theta*cng{1} $
             -nlconst $
             -nlygf*(yg{0}-theta*yg{1})
nlls(frml=fl,inst,iterations=100) * 63:3 94:3 cngresnomu


* Run OLS to generate initial values
linreg cng
# constant mu{1}
compute cngconst = %beta(1)
compute cngmu1 = %beta(2)

* Set initial estimates
compute nlconst = cngconst, nlmu1 = cngmu1
compute theta = .1

nonlin nlconst nlmu1 theta
display " "
frml fl = cng{0}-theta*cng{1} $
             -nlconst $
             -nlmu1*(mu{1}-theta*mu{2})
nlls(frml=fl,iterations=500) *



* Run OLS to generate initial values
linreg cng
# constant ygf mu{1}
compute cngconst = %beta(1)
compute cngygf = %beta(2)
compute cngmu1 = %beta(3)

* Set initial estimates
compute nlconst = cngconst, nlygf = cngygf, nlmu1 = cngmu1
compute theta = .1

nonlin nlconst nlygf nlmu1 theta
display " "
instruments constant cng{1 to 3} yg{1 to 3} mu{1} dtb3{1 to 3} dlhur{1 to 3} $
            spg{1 to 3} lcnmly{1}
frml fl = cng{0}-theta*cng{1} $
             -nlconst $
             -nlygf*(yg{0}-theta*yg{1}) $
             -nlmu1*(mu{1}-theta*mu{2})
nlls(frml=fl,inst,iterations=500) * 63:3 94:3 cngreswmu



* Run OLS to generate initial values
linreg yg / ygr
# constant cng{1 to 3} yg{1 to 3} mu{1} dtb3{1 to 3} dlhur{1 to 3} $
           spg{1 to 3} lcnmly{1} lbg{1}
set ygf = yg - ygr
linreg cng
# constant ygf mu{1} lbg{1}
compute cngconst = %beta(1)
compute cngygf = %beta(2)
compute cngmu1 = %beta(3)
compute cnglbg1 = %beta(4)

* Set initial estimates
compute nlconst = cngconst, nlygf = cngygf, nlmu1 = cngmu1, nllbg1 = cnglbg1
compute theta = .3

nonlin nlconst nlygf nlmu1 nllbg1 theta
display " "
instruments constant cng{1 to 3} yg{1 to 3} mu{1} dtb3{1 to 3} dlhur{1 to 3} $
            spg{1 to 3} lcnmly{1} lbg{1}
frml fl = cng{0}-theta*cng{1} $
             -nlconst $
             -nlygf*(yg{0}-theta*yg{1}) $
             -nlmu1*(mu{1}-theta*mu{2}) $
             -nllbg1*(lbg{1}-theta*lbg{2})
nlls(frml=fl,inst,iterations=500) *


* Run OLS to generate initial values
linreg yg / ygr
# constant cng{1 to 3} yg{1 to 3} mu{1} dtb3{1 to 3} dlhur{1 to 3} $
           spg{1 to 3} lcnmly{1} dsb{1}
set ygf = yg - ygr
linreg cng
# constant ygf mu{1} dsb{1}
compute cngconst = %beta(1)
compute cngygf = %beta(2)
compute cngmu1 = %beta(3)
compute cngdsb1 = %beta(4)

* Set initial estimates
compute nlconst = cngconst, nlygf = cngygf, nlmu1 = cngmu1, nldsb1 = cngdsb1
compute theta = .3

nonlin nlconst nlygf nlmu1 nldsb1 theta
display " "
instruments constant cng{1 to 3} yg{1 to 3} mu{1} dtb3{1 to 3} dlhur{1 to 3}  $
            spg{1 to 3} lcnmly{1} dsb{1}
frml fl = cng{0}-theta*cng{1} $
             -nlconst $
             -nlygf*(yg{0}-theta*yg{1}) $
             -nlmu1*(mu{1}-theta*mu{2}) $
             -nldsb1*(dsb{1}-theta*dsb{2})
nlls(frml=fl,inst,iterations=500) *


* Run OLS to generate initial values
linreg yg / ygr
# constant cng{1 to 3} yg{1 to 3} mu{1} dtb3{1 to 3} dlhur{1 to 3} $
           spg{1 to 3} lcnmly{1} lbozy{1}
set ygf = yg - ygr
linreg cng
# constant ygf mu{1} lbozy{1}
compute cngconst = %beta(1)
compute cngygf = %beta(2)
compute cngmu1 = %beta(3)
compute cnglbozy1 = %beta(4)

* Set initial estimates
compute nlconst = cngconst, nlygf = cngygf, nlmu1 = cngmu1, nllbozy1 = cnglbozy1
compute theta = .3

nonlin nlconst nlygf nlmu1 nllbozy1 theta
display " "
instruments constant cng{1 to 3} yg{1 to 3} mu{1} dtb3{1 to 3} dlhur{1 to 3} $
            spg{1 to 3} lcnmly{1} lbozy{1}
frml fl = cng{0}-theta*cng{1} $
             -nlconst $
             -nlygf*(yg{0}-theta*yg{1}) $
             -nlmu1*(mu{1}-theta*mu{2}) $
             -nllbozy1*(lbozy{1}-theta*lbozy{2})
nlls(frml=fl,inst,iterations=500) *

smpl

display ' '
display '************************      End Table 1 Results      ************************'
display '*******************************************************************************'
display ' '

















































